@@ -1,4 +1,3 @@
-# vim: encoding=utf-8 ts=4 et sts=4 sw=4 tw=79 fileformat=unix nu wm=2
 """Manage actions relating to the system running area28.
 
 The actions provided by the system module adds the ability to manage the state
@@ -11,13 +10,13 @@ from argparse import Namespace, _SubParsersAction
 from a28 import utils
 
 
-def options(mainparser: _SubParsersAction) -> None:
+def cli_options(mainparser: _SubParsersAction) -> None:
     """System subcommand arguments.
-    
+
     Define the arguments that the system subcommand can accept. The system
     subcommand supports the following commands:
-    
-    clean: Clena all files from the current system.
+
+    clean: Clean all files from the current system.
     exists: Return if the system currently contains a configuration.
     path: Return the current system configuration path.
     """
@@ -34,7 +33,7 @@ def options(mainparser: _SubParsersAction) -> None:
     parser.add_argument(
         '-p',
         '--path',
-        default=utils.STORAGE,
+        default=utils.CONFIG_PATH,
         help='configuration path.',
     )
     parser_exist = subparser.add_parser(
@@ -68,7 +67,7 @@ def options(mainparser: _SubParsersAction) -> None:
 
 def clean(args: Namespace) -> None:
     """Clean all the configuration files relating to Area28.
-    
+
     Using the shutil utilities, delete all the files provided in the STORAGE
     directory. If an error occurs, catch the exception and print it out to the
     STDOUT.
@@ -98,7 +97,7 @@ def clean(args: Namespace) -> None:
 
 def exists(args: Namespace) -> None:
     """Check if the configuration directory exists.
-    
+
     Using the path provided in the arguments, check if the configuration path
     exists. If no path is provided, the default path defined in the system
     utility is used.
@@ -117,7 +116,7 @@ def exists(args: Namespace) -> None:
 
 def path(args: Namespace) -> None:
     """Return the path of the system configuration.
-    
+
     Return the path currently used to store the system configuration files. If
     the path option is provided in the ArgParse Namespace, the provided path
     will be returned.
